@@ -14,11 +14,12 @@ class ContainerSettings(SettingsDefinition):
 
 def main(args):
     logger = get_logger(__name__)
+    container_settings = ContainerSettings.load(args=args)
     heare_client_settings = HeareClientSettings.load(args=args)
     client = HeareClient(config=heare_client_settings)
 
     skill_classes = []
-    for skill_str in heare_client_settings.skill.get():
+    for skill_str in container_settings.skill.get():
         try:
             module_name, klass_name = skill_str.rsplit('.', 1)
             mod = importlib.import_module(module_name)
